@@ -25,7 +25,7 @@ CONTEXT_SETTINGS = dict(
 			  '--subject', 
 			  prompt='Subject', 
 			  type=click.Choice(['Physics', 'Maths', 'Chemistry', 'Combined']), 
-			  cls=ChoiceOption
+			  cls=ChoiceOption,
 			  default='Physics',
 			  show_default=True)
 @click.option('-p',
